==> kubernetes-model-admissionregistration-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1/ResourceRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ResourceRuleFluentImpl<A extends ResourceRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ResourceRuleFluent<A> {

    private List<String> apiGroups = new ArrayList<String>();
    private List<String> resourceNames = new ArrayList<String>();
    private List<String> resources = new ArrayList<String>();
    private List<String> verbs = new ArrayList<String>();

    public ResourceRuleFluentImpl() { 
    }


    public ResourceRuleFluentImpl(ResourceRule instance) { 
        this.withApiGroups(instance.getApiGroups()); 
        this.withResourceNames(instance.getResourceNames()); 
        this.withResources(instance.getResources()); 
        this.withVerbs(instance.getVerbs()); 
    }


    public A addToApiGroups(int index,String item) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        this.apiGroups.add(index, item);
        return (A)this;
    }

    public A setToApiGroups(int index,String item) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        this.apiGroups.set(index, item); return (A)this;
    }

    public A addToApiGroups(String... items) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        for (String item : items) {this.apiGroups.add(item);} return (A)this;
    }

    public A addAllToApiGroups(Collection<String> items) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        for (String item : items) {this.apiGroups.add(item);} return (A)this;
    }

    public A removeFromApiGroups(String... items) {
        for (String item : items) {if (this.apiGroups!= null){ this.apiGroups.remove(item);}} return (A)this;
    }

    public A removeAllFromApiGroups(Collection<String> items) {
        for (String item : items) {if (this.apiGroups!= null){ this.apiGroups.remove(item);}} return (A)this;
    }

    public List<String> getApiGroups() {
        return this.apiGroups;
    }

    public String getApiGroup(int index) {
        return this.apiGroups.get(index);
    }

    public String getFirstApiGroup() {
        return this.apiGroups.get(0);
    }

    public String getLastApiGroup() {
        return this.apiGroups.get(apiGroups.size() - 1);
    }

    public String getMatchingApiGroup(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: apiGroups) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingApiGroup(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: apiGroups) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withApiGroups(List<String> apiGroups) {
        if (this.apiGroups != null) { _visitables.get("apiGroups").removeAll(this.apiGroups);}
        if (apiGroups != null) {this.apiGroups = new ArrayList<String>(); for (String item : apiGroups){this.addToApiGroups(item);}} else { this.apiGroups = null;} return (A) this;
    }

    public A withApiGroups(String... apiGroups) {
        if (this.apiGroups != null) {this.apiGroups.clear();}
        if (apiGroups != null) {for (String item :apiGroups){ this.addToApiGroups(item);}} return (A) this;
    }

    public Boolean hasApiGroups() {
        return apiGroups != null && !apiGroups.isEmpty();
    }

    public A addNewApiGroup(String arg1) {
        return (A)addToApiGroups(new String(arg1));
    }

    public A addNewApiGroup(StringBuilder arg1) {
        return (A)addToApiGroups(new String(arg1));
    }

    public A addNewApiGroup(StringBuffer arg1) {
        return (A)addToApiGroups(new String(arg1));
    }

    public A addToResourceNames(int index,String item) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        this.resourceNames.add(index, item);
        return (A)this;
    }

    public A setToResourceNames(int index,String item) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        this.resourceNames.set(index, item); return (A)this;
    }

    public A addToResourceNames(String... items) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        for (String item : items) {this.resourceNames.add(item);} return (A)this;
    }

    public A addAllToResourceNames(Collection<String> items) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        for (String item : items) {this.resourceNames.add(item);} return (A)this;
    }

    public A removeFromResourceNames(String... items) {
        for (String item : items) {if (this.resourceNames!= null){ this.resourceNames.remove(item);}} return (A)this;
    }

    public A removeAllFromResourceNames(Collection<String> items) {
        for (String item : items) {if (this.resourceNames!= null){ this.resourceNames.remove(item);}} return (A)this;
    }

    public List<String> getResourceNames() {
        return this.resourceNames;
    }

    public String getResourceName(int index) {
        return this.resourceNames.get(index);
    }

    public String getFirstResourceName() {
        return this.resourceNames.get(0);
    }

    public String getLastResourceName() {
        return this.resourceNames.get(resourceNames.size() - 1);
    }

    public String getMatchingResourceName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: resourceNames) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingResourceName(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: resourceNames) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withResourceNames(List<String> resourceNames) {
        if (this.resourceNames != null) { _visitables.get("resourceNames").removeAll(this.resourceNames);}
        if (resourceNames != null) {this.resourceNames = new ArrayList<String>(); for (String item : resourceNames){this.addToResourceNames(item);}} else { this.resourceNames = null;} return (A) this;
    }

    public A withResourceNames(String... resourceNames) {
        if (this.resourceNames != null) {this.resourceNames.clear();}
        if (resourceNames != null) {for (String item :resourceNames){ this.addToResourceNames(item);}} return (A) this;
    }

    public Boolean hasResourceNames() {
        return resourceNames != null && !resourceNames.isEmpty();
    }

    public A addNewResourceName(String arg1) {
        return (A)addToResourceNames(new String(arg1));
    }

    public A addNewResourceName(StringBuilder arg1) {
        return (A)addToResourceNames(new String(arg1));
    }

    public A addNewResourceName(StringBuffer arg1) {
        return (A)addToResourceNames(new String(arg1));
    }

    public A addToResources(int index,String item) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        this.resources.add(index, item);
        return (A)this;
    }

    public A setToResources(int index,String item) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        this.resources.set(index, item); return (A)this;
    }

    public A addToResources(String... items) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        for (String item : items) {this.resources.add(item);} return (A)this;
    }

    public A addAllToResources(Collection<String> items) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        for (String item : items) {this.resources.add(item);} return (A)this;
    }

    public A removeFromResources(String... items) {
        for (String item : items) {if (this.resources!= null){ this.resources.remove(item);}} return (A)this;
    }

    public A removeAllFromResources(Collection<String> items) {
        for (String item : items) {if (this.resources!= null){ this.resources.remove(item);}} return (A)this;
    }

    public List<String> getResources() {
        return this.resources;
    }

    public String getResource(int index) {
        return this.resources.get(index);
    }

    public String getFirstResource() {
        return this.resources.get(0);
    }

    public String getLastResource() {
        return this.resources.get(resources.size() - 1);
    }

    public String getMatchingResource(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: resources) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingResource(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: resources) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withResources(List<String> resources) {
        if (this.resources != null) { _visitables.get("resources").removeAll(this.resources);}
        if (resources != null) {this.resources = new ArrayList<String>(); for (String item : resources){this.addToResources(item);}} else { this.resources = null;} return (A) this;
    }

    public A withResources(String... resources) {
        if (this.resources != null) {this.resources.clear();}
        if (resources != null) {for (String item :resources){ this.addToResources(item);}} return (A) this;
    }

    public Boolean hasResources() {
        return resources != null && !resources.isEmpty();
    }

    public A addNewResource(String arg1) {
        return (A)addToResources(new String(arg1));
    }

    public A addNewResource(StringBuilder arg1) {
        return (A)addToResources(new String(arg1));
    }

    public A addNewResource(StringBuffer arg1) {
        return (A)addToResources(new String(arg1));
    }

    public A addToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.add(index, item);
        return (A)this;
    }

    public A setToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.set(index, item); return (A)this;
    }

    public A addToVerbs(String... items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A addAllToVerbs(Collection<String> items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A removeFromVerbs(String... items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public A removeAllFromVerbs(Collection<String> items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public List<String> getVerbs() {
        return this.verbs;
    }

    public String getVerb(int index) {
        return this.verbs.get(index);
    }

    public String getFirstVerb() {
        return this.verbs.get(0);
    }

    public String getLastVerb() {
        return this.verbs.get(verbs.size() - 1);
    }

    public String getMatchingVerb(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.apply(item)){ return item;} } return null;
    }

    public Boolean hasMatchingVerb(io.fabric8.kubernetes.api.builder.Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.apply(item)){ return true;} } return false;
    }

    public A withVerbs(List<String> verbs) {
        if (this.verbs != null) { _visitables.get("verbs").removeAll(this.verbs);}
        if (verbs != null) {this.verbs = new ArrayList<String>(); for (String item : verbs){this.addToVerbs(item);}} else { this.verbs = null;} return (A) this;
    }

    public A withVerbs(String... verbs) {
        if (this.verbs != null) {this.verbs.clear();}
        if (verbs != null) {for (String item :verbs){ this.addToVerbs(item);}} return (A) this;
    }

    public Boolean hasVerbs() {
        return verbs != null && !verbs.isEmpty();
    }

    public A addNewVerb(String arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuilder arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuffer arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ResourceRuleFluentImpl that = (ResourceRuleFluentImpl) o;
        if (apiGroups != null ? !apiGroups.equals(that.apiGroups) :that.apiGroups != null) return false;
        if (resourceNames != null ? !resourceNames.equals(that.resourceNames) :that.resourceNames != null) return false;
        if (resources != null ? !resources.equals(that.resources) :that.resources != null) return false;
        if (verbs != null ? !verbs.equals(that.verbs) :that.verbs != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiGroups,  resourceNames,  resources,  verbs,  super.hashCode());
    }

}

==> kubernetes-model-admissionregistration-5.0.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1/ResourceRuleFluentImpl.java <==
package io.fabric8.kubernetes.api.model.authorization.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

public class ResourceRuleFluentImpl<A extends ResourceRuleFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ResourceRuleFluent<A> {

    private List<String> apiGroups = new ArrayList<String>();
    private List<String> resourceNames = new ArrayList<String>();
    private List<String> resources = new ArrayList<String>();
    private List<String> verbs = new ArrayList<String>();

    public ResourceRuleFluentImpl() { 
    }


    public ResourceRuleFluentImpl(ResourceRule instance) { 
        this.withApiGroups(instance.getApiGroups()); 
        this.withResourceNames(instance.getResourceNames()); 
        this.withResources(instance.getResources()); 
        this.withVerbs(instance.getVerbs()); 
    }


    public A addToApiGroups(int index,String item) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        this.apiGroups.add(index, item);
        return (A)this;
    }

    public A setToApiGroups(int index,String item) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        this.apiGroups.set(index, item); return (A)this;
    }

    public A addToApiGroups(String... items) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        for (String item : items) {this.apiGroups.add(item);} return (A)this;
    }

    public A addAllToApiGroups(Collection<String> items) {
        if (this.apiGroups == null) {this.apiGroups = new ArrayList<String>();}
        for (String item : items) {this.apiGroups.add(item);} return (A)this;
    }

    public A removeFromApiGroups(String... items) {
        for (String item : items) {if (this.apiGroups!= null){ this.apiGroups.remove(item);}} return (A)this;
    }

    public A removeAllFromApiGroups(Collection<String> items) {
        for (String item : items) {if (this.apiGroups!= null){ this.apiGroups.remove(item);}} return (A)this;
    }

    public List<String> getApiGroups() {
        return this.apiGroups;
    }

    public String getApiGroup(int index) {
        return this.apiGroups.get(index);
    }

    public String getFirstApiGroup() {
        return this.apiGroups.get(0);
    }

    public String getLastApiGroup() {
        return this.apiGroups.get(apiGroups.size() - 1);
    }

    public String getMatchingApiGroup(Predicate<String> predicate) {
        for (String item: apiGroups) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingApiGroup(Predicate<String> predicate) {
        for (String item: apiGroups) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withApiGroups(List<String> apiGroups) {
        if (this.apiGroups != null) { _visitables.get("apiGroups").removeAll(this.apiGroups);}
        if (apiGroups != null) {this.apiGroups = new ArrayList<String>(); for (String item : apiGroups){this.addToApiGroups(item);}} else { this.apiGroups = null;} return (A) this;
    }

    public A withApiGroups(String... apiGroups) {
        if (this.apiGroups != null) {this.apiGroups.clear();}
        if (apiGroups != null) {for (String item :apiGroups){ this.addToApiGroups(item);}} return (A) this;
    }

    public Boolean hasApiGroups() {
        return apiGroups != null && !apiGroups.isEmpty();
    }

    public A addNewApiGroup(String arg1) {
        return (A)addToApiGroups(new String(arg1));
    }

    public A addNewApiGroup(StringBuilder arg1) {
        return (A)addToApiGroups(new String(arg1));
    }

    public A addNewApiGroup(StringBuffer arg1) {
        return (A)addToApiGroups(new String(arg1));
    }

    public A addToResourceNames(int index,String item) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        this.resourceNames.add(index, item);
        return (A)this;
    }

    public A setToResourceNames(int index,String item) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        this.resourceNames.set(index, item); return (A)this;
    }

    public A addToResourceNames(String... items) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        for (String item : items) {this.resourceNames.add(item);} return (A)this;
    }

    public A addAllToResourceNames(Collection<String> items) {
        if (this.resourceNames == null) {this.resourceNames = new ArrayList<String>();}
        for (String item : items) {this.resourceNames.add(item);} return (A)this;
    }

    public A removeFromResourceNames(String... items) {
        for (String item : items) {if (this.resourceNames!= null){ this.resourceNames.remove(item);}} return (A)this;
    }

    public A removeAllFromResourceNames(Collection<String> items) {
        for (String item : items) {if (this.resourceNames!= null){ this.resourceNames.remove(item);}} return (A)this;
    }

    public List<String> getResourceNames() {
        return this.resourceNames;
    }

    public String getResourceName(int index) {
        return this.resourceNames.get(index);
    }

    public String getFirstResourceName() {
        return this.resourceNames.get(0);
    }

    public String getLastResourceName() {
        return this.resourceNames.get(resourceNames.size() - 1);
    }

    public String getMatchingResourceName(Predicate<String> predicate) {
        for (String item: resourceNames) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingResourceName(Predicate<String> predicate) {
        for (String item: resourceNames) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withResourceNames(List<String> resourceNames) {
        if (this.resourceNames != null) { _visitables.get("resourceNames").removeAll(this.resourceNames);}
        if (resourceNames != null) {this.resourceNames = new ArrayList<String>(); for (String item : resourceNames){this.addToResourceNames(item);}} else { this.resourceNames = null;} return (A) this;
    }

    public A withResourceNames(String... resourceNames) {
        if (this.resourceNames != null) {this.resourceNames.clear();}
        if (resourceNames != null) {for (String item :resourceNames){ this.addToResourceNames(item);}} return (A) this;
    }

    public Boolean hasResourceNames() {
        return resourceNames != null && !resourceNames.isEmpty();
    }

    public A addNewResourceName(String arg1) {
        return (A)addToResourceNames(new String(arg1));
    }

    public A addNewResourceName(StringBuilder arg1) {
        return (A)addToResourceNames(new String(arg1));
    }

    public A addNewResourceName(StringBuffer arg1) {
        return (A)addToResourceNames(new String(arg1));
    }

    public A addToResources(int index,String item) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        this.resources.add(index, item);
        return (A)this;
    }

    public A setToResources(int index,String item) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        this.resources.set(index, item); return (A)this;
    }

    public A addToResources(String... items) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        for (String item : items) {this.resources.add(item);} return (A)this;
    }

    public A addAllToResources(Collection<String> items) {
        if (this.resources == null) {this.resources = new ArrayList<String>();}
        for (String item : items) {this.resources.add(item);} return (A)this;
    }

    public A removeFromResources(String... items) {
        for (String item : items) {if (this.resources!= null){ this.resources.remove(item);}} return (A)this;
    }

    public A removeAllFromResources(Collection<String> items) {
        for (String item : items) {if (this.resources!= null){ this.resources.remove(item);}} return (A)this;
    }

    public List<String> getResources() {
        return this.resources;
    }

    public String getResource(int index) {
        return this.resources.get(index);
    }

    public String getFirstResource() {
        return this.resources.get(0);
    }

    public String getLastResource() {
        return this.resources.get(resources.size() - 1);
    }

    public String getMatchingResource(Predicate<String> predicate) {
        for (String item: resources) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingResource(Predicate<String> predicate) {
        for (String item: resources) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withResources(List<String> resources) {
        if (this.resources != null) { _visitables.get("resources").removeAll(this.resources);}
        if (resources != null) {this.resources = new ArrayList<String>(); for (String item : resources){this.addToResources(item);}} else { this.resources = null;} return (A) this;
    }

    public A withResources(String... resources) {
        if (this.resources != null) {this.resources.clear();}
        if (resources != null) {for (String item :resources){ this.addToResources(item);}} return (A) this;
    }

    public Boolean hasResources() {
        return resources != null && !resources.isEmpty();
    }

    public A addNewResource(String arg1) {
        return (A)addToResources(new String(arg1));
    }

    public A addNewResource(StringBuilder arg1) {
        return (A)addToResources(new String(arg1));
    }

    public A addNewResource(StringBuffer arg1) {
        return (A)addToResources(new String(arg1));
    }

    public A addToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.add(index, item);
        return (A)this;
    }

    public A setToVerbs(int index,String item) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        this.verbs.set(index, item); return (A)this;
    }

    public A addToVerbs(String... items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A addAllToVerbs(Collection<String> items) {
        if (this.verbs == null) {this.verbs = new ArrayList<String>();}
        for (String item : items) {this.verbs.add(item);} return (A)this;
    }

    public A removeFromVerbs(String... items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public A removeAllFromVerbs(Collection<String> items) {
        for (String item : items) {if (this.verbs!= null){ this.verbs.remove(item);}} return (A)this;
    }

    public List<String> getVerbs() {
        return this.verbs;
    }

    public String getVerb(int index) {
        return this.verbs.get(index);
    }

    public String getFirstVerb() {
        return this.verbs.get(0);
    }

    public String getLastVerb() {
        return this.verbs.get(verbs.size() - 1);
    }

    public String getMatchingVerb(Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.test(item)){ return item;} } return null;
    }

    public Boolean hasMatchingVerb(Predicate<String> predicate) {
        for (String item: verbs) { if(predicate.test(item)){ return true;} } return false;
    }

    public A withVerbs(List<String> verbs) {
        if (this.verbs != null) { _visitables.get("verbs").removeAll(this.verbs);}
        if (verbs != null) {this.verbs = new ArrayList<String>(); for (String item : verbs){this.addToVerbs(item);}} else { this.verbs = null;} return (A) this;
    }

    public A withVerbs(String... verbs) {
        if (this.verbs != null) {this.verbs.clear();}
        if (verbs != null) {for (String item :verbs){ this.addToVerbs(item);}} return (A) this;
    }

    public Boolean hasVerbs() {
        return verbs != null && !verbs.isEmpty();
    }

    public A addNewVerb(String arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuilder arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public A addNewVerb(StringBuffer arg1) {
        return (A)addToVerbs(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ResourceRuleFluentImpl that = (ResourceRuleFluentImpl) o;
        if (apiGroups != null ? !apiGroups.equals(that.apiGroups) :that.apiGroups != null) return false;
        if (resourceNames != null ? !resourceNames.equals(that.resourceNames) :that.resourceNames != null) return false;
        if (resources != null ? !resources.equals(that.resources) :that.resources != null) return false;
        if (verbs != null ? !verbs.equals(that.verbs) :that.verbs != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(apiGroups,  resourceNames,  resources,  verbs,  super.hashCode());
    }

}
